<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.divydovy.com
 * @since             1.0.0
 * @package           Simple_Web_Monetization_Wordpress_Interledger
 *
 * @wordpress-plugin
 * Plugin Name:       Simple Web Monetization by Interledger
 * Plugin URI:        https://github.com/interledger/simple-web-monetization-interledger
 * Description:       A simple plugin to add Web Monetization to a WordPress site.
 * Version:           1.0.0
 * Author:            David Lockie
 * Author URI:        https://www.divydovy.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       simple-web-monetization-wordpress-interledger
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'SIMPLE_WEB_MONETIZATION_WORDPRESS_INTERLEDGER_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-simple-web-monetization-wordpress-interledger-activator.php
 */
function activate_simple_web_monetization_wordpress_interledger() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-simple-web-monetization-wordpress-interledger-activator.php';
	Simple_Web_Monetization_Wordpress_Interledger_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-simple-web-monetization-wordpress-interledger-deactivator.php
 */
function deactivate_simple_web_monetization_wordpress_interledger() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-simple-web-monetization-wordpress-interledger-deactivator.php';
	Simple_Web_Monetization_Wordpress_Interledger_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_simple_web_monetization_wordpress_interledger' );
register_deactivation_hook( __FILE__, 'deactivate_simple_web_monetization_wordpress_interledger' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-simple-web-monetization-wordpress-interledger.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_simple_web_monetization_wordpress_interledger() {

	$plugin = new Simple_Web_Monetization_Wordpress_Interledger();
	$plugin->run();

}
run_simple_web_monetization_wordpress_interledger();
